@@ -3,13 +3,16 @@
 
 # Set up common credentials for testing
 # oraclepool vs. oracle functionality & performance 
-CREDENTIALS = {'USER' : 'SCOTT',      
-               'NAME' : 'SCOTT',             
-               'PASSWORD' : 'TIGER',     
-               'HOST' : 'localhost', 
-               'PORT' : '1521',            
-               'OPTIONS' : {}
-               }
+try:
+    from cred import CREDENTIALS
+except:
+    CREDENTIALS = {'USER' : 'SCOTT',      
+                   'NAME' : 'SCOTT',             
+                   'PASSWORD' : 'TIGER',     
+                   'HOST' : 'localhost', 
+                   'PORT' : '1521',            
+                   'OPTIONS' : {}
+                   }
 
 # NB: Oracle already has OPTIONS dict so use EXTRAS for pooling and logging
 EXTRAS = {'min':4,         # start number of connections
@@ -129,7 +132,7 @@ TEMPLATE_DIRS = (
 INSTALLED_APPS = (
     'performance',
     'apitest',
-    'regressiontests',
+    'regress',
     'slicing',
     'nulls',
     'aggregates'
